@@ -22,7 +22,8 @@ while [[ "$#" -gt 0 ]]; do
 done
 # if not set, compute from current branch
 if [[ ! ${JOB_BRANCH} ]]; then 
-	JOB_BRANCH=$(git rev-parse --abbrev-ref HEAD); JOB_BRANCH=${JOB_BRANCH//crw-}; JOB_BRANCH=${JOB_BRANCH%%-rhel*}; 
+	JOB_BRANCH=$(git rev-parse --abbrev-ref HEAD); JOB_BRANCH=${JOB_BRANCH//crw-}; JOB_BRANCH=${JOB_BRANCH%%-rhel*}
+	if [[ ${JOB_BRANCH} == "2" ]]; then JOB_BRANCH="2.x"; fi
 fi
 UPSTREAM_JOB_NAME="crw-traefik_${JOB_BRANCH}"
 
